==> grafana-10.3.0.linux-amd64.tar.gz: grafana-v10.3.0/docs/sources/alerting/fundamentals/alert-rules/organising-alerts.md <==
---
aliases:
  - ../unified-alerting/alerting-rules/edit-cortex-loki-namespace-group/
    - ../unified-alerting/alerting-rules/edit-mimir-loki-namespace-group/
canonical: https://grafana.com/docs/grafana/latest/alerting/fundamentals/alert-rules/organising-alerts/
description: Learn about organizing alerts using namespaces, folders, and groups
keywords:
  - grafana
  - alerting
  - organization
labels:
  products:
    - cloud
    - enterprise
    - oss
title: Namespaces, folders, and groups
weight: 105
---

## Namespaces, folders, and groups

Alerts can be organized using folders for Grafana-managed rules and namespaces for Mimir or Loki rules and group names.

### Namespaces and folders

When creating Grafana-managed rules, the folder can be used to perform access control and grant or deny access to all rules within a specific folder.

A namespace contains one or more groups. The rules within a group are run sequentially at a regular interval. The default interval is one (1) minute. You can rename Grafana Mimir or Loki rule namespaces and groups, and edit group evaluation intervals.

### Groups

The rules within a group are run sequentially at a regular interval, meaning no rules will be evaluated at the same time and in order of appearance. The default interval is one (1) minute. You can rename Grafana Mimir or Loki rule namespaces and groups, and edit group evaluation intervals.

> **Note** If you want rules to be evaluated concurrently and with different intervals, consider storing them in different groups.

> **Note** Grafana managed alert rules are evaluated concurrently instead of sequentially.

==> grafana-11.0.0.linux-amd64.tar.gz: grafana-v11.0.0/docs/sources/alerting/fundamentals/alert-rules/organising-alerts.md <==
---
aliases:
  - ../../unified-alerting/alerting-rules/edit-cortex-loki-namespace-group/ # /docs/grafana/<GRAFANA_VERSION>/alerting/unified-alerting/alerting-rules/edit-cortex-loki-namespace-group/
  - ../../unified-alerting/alerting-rules/edit-mimir-loki-namespace-group/ # /docs/grafana/<GRAFANA_VERSION>/alerting/unified-alerting/alerting-rules/edit-mimir-loki-namespace-group/
canonical: https://grafana.com/docs/grafana/latest/alerting/fundamentals/alert-rules/organising-alerts/
description: Learn about organizing alerts using namespaces, folders, and groups
keywords:
  - grafana
  - alerting
  - organization
labels:
  products:
    - cloud
    - enterprise
    - oss
title: Namespaces, folders, and groups
weight: 107
---

## Namespaces, folders, and groups

Alerts can be organized using folders for Grafana-managed rules and namespaces for Mimir or Loki rules and group names.

### Namespaces and folders

When creating Grafana-managed rules, the folder can be used to perform access control and grant or deny access to all rules within a specific folder.

A namespace contains one or more groups. The rules within a group are run sequentially at a regular interval. The default interval is one (1) minute. You can rename Grafana Mimir or Loki rule namespaces and groups, and edit group evaluation intervals.

### Groups

The rules within a group are run sequentially at a regular interval, meaning no rules will be evaluated at the same time and in order of appearance. The default interval is one (1) minute. You can rename Grafana Mimir or Loki rule namespaces and groups, and edit group evaluation intervals.

> **Note** If you want rules to be evaluated concurrently and with different intervals, consider storing them in different groups.

> **Note** Grafana managed alert rules are evaluated concurrently instead of sequentially.
